package com.wificam.camera;

import java.io.IOException;

import com.wificam.network.IDataSender;

import android.graphics.ImageFormat;
import android.hardware.Camera;
import android.util.Log;

// kameranin sistemden alinmasi ve release edilmesi
// kamera ozellik ayari: fps, cozunurluk, bitrate,
// preview callback
// kamera sayisi

public class CameraManager implements Camera.PreviewCallback {
	
	private Camera cam;
	private Camera.Parameters camParam;
	private byte[] buf;
	
	private IDataSender dataSender;
	
	public CameraManager() {
		
		cam = null;
		camParam = null;
		buf = null;
	}
	
	// kameranin hazirlanmasi
	public void prepareCamera() {
    	
		// kameranin sistemden alinmasi
    	try {
    		
    		cam = Camera.open();	// backface camera
    		
    	} catch(Exception e) {
    		
    		Log.i(getClass().getSimpleName(), e.getMessage());
    	}
    	
    	// kameranin hazirlanmasi
    	if (cam != null) {
    		
    		camParam = cam.getParameters();
    		
    		cam.unlock();
    		
    		try {
    			
    			cam.reconnect();
    		} catch (IOException e) {
				
    			Log.i(getClass().getSimpleName(), e.getMessage());
			}
    		
    		camParam.setPreviewSize(176, 144);
    		//camParam.setPreviewFormat(ImageFormat.NV16);
    		
    		cam.setParameters(camParam);
    		
    		// bu kisma fonksiyonalite kazandirilacak
    		int bitPerPixel = ImageFormat.getBitsPerPixel(camParam.getPreviewFormat());
    		Camera.Size camSize = camParam.getPreviewSize();
    		int frameSize = (camSize.width * camSize.height) * bitPerPixel / 8;
    		
    		buf = new byte[frameSize];
    	}
    }
	
	// kameranin serbest birakilmasi
	public void releaseCamera() {
		
		if (cam != null) {
			
			cam.release();
			cam = null;
		}
	}
	
	// cam instance getter
	public Camera getCam() {
		
		return cam;
	}

	// kameradan data alimina baslar
	public void cameraPreview() {
		
		if (cam != null) {
		
			cam.addCallbackBuffer(buf);
			cam.setPreviewCallbackWithBuffer(this);
			cam.startPreview();
		}
	}

	@Override
	public void onPreviewFrame(byte[] data, Camera camera) {
		
		Log.i("camera", String.valueOf(data.length));
		
		//dataSender.sendData(data);
		cam.addCallbackBuffer(data); 
	}
	
	public void setDataSender(IDataSender dataSender) {
		this.dataSender = dataSender;
	}
	
}
